@@ -7,8 +7,7 @@ has parts => sub { [] };
 
 sub body_contains {
   my ($self, $chunk) = @_;
-  ($_->headers_contain($chunk) or $_->body_contains($chunk)) and return 1
-    for @{$self->parts};
+  ($_->headers_contain($chunk) or $_->body_contains($chunk)) and return 1 for @{$self->parts};
   return undef;
 }
 
@@ -42,8 +41,7 @@ sub build_boundary {
   # Add boundary to Content-Type header
   my $headers = $self->headers;
   my ($before, $after) = ('multipart/mixed', '');
-  ($before, $after) = ($1, $2)
-    if ($headers->content_type // '') =~ m!^(.*multipart/[^;]+)(.*)$!;
+  ($before, $after) = ($1, $2) if ($headers->content_type // '') =~ m!^(.*multipart/[^;]+)(.*)$!;
   $headers->content_type("$before; boundary=$boundary$after");
 
   return $boundary;
@@ -69,8 +67,7 @@ sub get_body_chunk {
 
   # Skip parts that have already been processed
   my $start = 0;
-  ($len, $start) = ($self->{last_len}, $self->{last_part} + 1)
-    if $self->{offset} && $offset > $self->{offset};
+  ($len, $start) = ($self->{last_len}, $self->{last_part} + 1) if $self->{offset} && $offset > $self->{offset};
 
   # Prepare content part by part
   my $parts = $self->parts;
@@ -79,14 +76,12 @@ sub get_body_chunk {
 
     # Headers
     my $header_len = $part->header_size;
-    return $part->get_header_chunk($offset - $len)
-      if ($len + $header_len) > $offset;
+    return $part->get_header_chunk($offset - $len) if ($len + $header_len) > $offset;
     $len += $header_len;
 
     # Content
     my $content_len = $part->body_size;
-    return $part->get_body_chunk($offset - $len)
-      if ($len + $content_len) > $offset;
+    return $part->get_body_chunk($offset - $len) if ($len + $content_len) > $offset;
     $len += $content_len;
 
     # Boundary
@@ -94,8 +89,7 @@ sub get_body_chunk {
       $boundary .= '--';
       $boundary_len += 2;
     }
-    return substr "\x0d\x0a--$boundary\x0d\x0a", $offset - $len
-      if ($len + $boundary_len) > $offset;
+    return substr "\x0d\x0a--$boundary\x0d\x0a", $offset - $len if ($len + $boundary_len) > $offset;
     $len += $boundary_len;
 
     @{$self}{qw(last_len last_part offset)} = ($len, $i, $offset);
@@ -192,8 +186,7 @@ sub _read {
   }
 
   # Check buffer size
-  @$self{qw(state limit)} = ('finished', 1)
-    if length($self->{multipart} // '') > $self->max_buffer_size;
+  @$self{qw(state limit)} = ('finished', 1) if length($self->{multipart} // '') > $self->max_buffer_size;
 }
 
 1;
@@ -214,15 +207,13 @@ Mojo::Content::MultiPart - HTTP multipart content
 
 =head1 DESCRIPTION
 
-L<Mojo::Content::MultiPart> is a container for HTTP multipart content, based on
-L<RFC 7230|http://tools.ietf.org/html/rfc7230>,
-L<RFC 7231|http://tools.ietf.org/html/rfc7231> and
-L<RFC 2388|http://tools.ietf.org/html/rfc2388>.
+L<Mojo::Content::MultiPart> is a container for HTTP multipart content, based on L<RFC
+7230|http://tools.ietf.org/html/rfc7230>, L<RFC 7231|http://tools.ietf.org/html/rfc7231> and L<RFC
+2388|http://tools.ietf.org/html/rfc2388>.
 
 =head1 EVENTS
 
-L<Mojo::Content::Multipart> inherits all events from L<Mojo::Content> and can
-emit the following new ones.
+L<Mojo::Content::Multipart> inherits all events from L<Mojo::Content> and can emit the following new ones.
 
 =head2 part
 
@@ -241,21 +232,18 @@ Emitted when a new L<Mojo::Content::Single> part starts.
 
 =head1 ATTRIBUTES
 
-L<Mojo::Content::MultiPart> inherits all attributes from L<Mojo::Content> and
-implements the following new ones.
+L<Mojo::Content::MultiPart> inherits all attributes from L<Mojo::Content> and implements the following new ones.
 
 =head2 parts
 
   my $parts = $multi->parts;
   $multi    = $multi->parts([Mojo::Content::Single->new]);
 
-Content parts embedded in this multipart content, usually
-L<Mojo::Content::Single> objects.
+Content parts embedded in this multipart content, usually L<Mojo::Content::Single> objects.
 
 =head1 METHODS
 
-L<Mojo::Content::MultiPart> inherits all methods from L<Mojo::Content> and
-implements the following new ones.
+L<Mojo::Content::MultiPart> inherits all methods from L<Mojo::Content> and implements the following new ones.
 
 =head2 body_contains
 
@@ -279,16 +267,14 @@ Generate a suitable boundary for content and add it to C<Content-Type> header.
 
   my $clone = $multi->clone;
 
-Return a new L<Mojo::Content::MultiPart> object cloned from this content if
-possible, otherwise return C<undef>.
+Return a new L<Mojo::Content::MultiPart> object cloned from this content if possible, otherwise return C<undef>.
 
 =head2 get_body_chunk
 
   my $bytes = $multi->get_body_chunk(0);
 
-Get a chunk of content starting from a specific position. Note that it might
-not be possible to get the same chunk twice if content was generated
-dynamically.
+Get a chunk of content starting from a specific position. Note that it might not be possible to get the same chunk
+twice if content was generated dynamically.
 
 =head2 is_multipart
 
@@ -304,8 +290,8 @@ True, this is a L<Mojo::Content::MultiPart> object.
   my $multi
     = Mojo::Content::MultiPart->new({parts => [Mojo::Content::Single->new]});
 
-Construct a new L<Mojo::Content::MultiPart> object and subscribe to event
-L<Mojo::Content/"read"> with default content parser.
+Construct a new L<Mojo::Content::MultiPart> object and subscribe to event L<Mojo::Content/"read"> with default content
+parser.
 
 =head1 SEE ALSO
 
