@@ -8,7 +8,7 @@ use Scalar::Util qw(blessed);
 
 has [qw(frames line lines_after lines_before)] => sub { [] };
 has message                                    => 'Exception!';
-has verbose => sub { $ENV{MOJO_EXCEPTION_VERBOSE} };
+has verbose                                    => sub { $ENV{MOJO_EXCEPTION_VERBOSE} };
 
 our @EXPORT_OK = qw(check raise);
 
@@ -198,19 +198,16 @@ L<Mojo::Exception> is a container for exceptions with context information.
 
 =head1 FUNCTIONS
 
-L<Mojo::Exception> implements the following functions, which can be imported
-individually.
+L<Mojo::Exception> implements the following functions, which can be imported individually.
 
 =head2 check
 
   my $bool = check 'MyApp::X::Foo' => sub {...};
   my $bool = check $err, 'MyApp::X::Foo' => sub {...};
 
-Process exceptions by dispatching them to handlers with one or more matching
-conditions. Exceptions that could not be handled will be rethrown automatically.
-By default C<$@> will be used as exception source, so C<check> needs to be
-called right after C<eval>. Note that this function is B<EXPERIMENTAL> and might
-change without warning!
+Process exceptions by dispatching them to handlers with one or more matching conditions. Exceptions that could not be
+handled will be rethrown automatically. By default C<$@> will be used as exception source, so C<check> needs to be
+called right after C<eval>. Note that this function is B<EXPERIMENTAL> and might change without warning!
 
   # Handle various types of exceptions
   eval {
@@ -223,10 +220,9 @@ change without warning!
     finally             => sub { say 'Dangerous code is done' }
   );
 
-Matching conditions can be class names for ISA checks on exception objects, or
-regular expressions to match string exceptions and stringified exception
-objects. The matching exception will be the first argument passed to the
-callback, and is also available as C<$_>.
+Matching conditions can be class names for ISA checks on exception objects, or regular expressions to match string
+exceptions and stringified exception objects. The matching exception will be the first argument passed to the callback,
+and is also available as C<$_>.
 
   # Catch MyApp::X::Foo object or a specific string exception
   eval {
@@ -237,9 +233,8 @@ callback, and is also available as C<$_>.
     qr/^Could not open/ => sub { say "Open error: $_" }
   );
 
-An array reference can be used to share the same handler with multiple
-conditions, of which only one needs to match. And since exception handlers are
-just callbacks, they can also throw their own exceptions.
+An array reference can be used to share the same handler with multiple conditions, of which only one needs to match.
+And since exception handlers are just callbacks, they can also throw their own exceptions.
 
   # Handle MyApp::X::Foo and MyApp::X::Bar the same
   eval {
@@ -249,9 +244,8 @@ just callbacks, they can also throw their own exceptions.
     ['MyApp::X::Foo', 'MyApp::X::Bar'] => sub { die "Foo/Bar: $_" }
   );
 
-There are currently two keywords you can use to set special handlers. The
-C<default> handler is used when no other handler matched. And the C<finally>
-handler runs always, it does not affect normal handlers and even runs if the
+There are currently two keywords you can use to set special handlers. The C<default> handler is used when no other
+handler matched. And the C<finally> handler runs always, it does not affect normal handlers and even runs if the
 exception was rethrown or if there was no exception to be handled at all.
 
   # Use "default" to catch everything
@@ -268,9 +262,9 @@ exception was rethrown or if there was no exception to be handled at all.
   raise 'Something went wrong!';
   raise 'MyApp::X::Foo', 'Something went wrong!';
 
-Raise a L<Mojo::Exception>, if the class does not exist yet (classes are checked
-for a C<new> method), one is created as a L<Mojo::Exception> subclass on demand.
-Note that this function is B<EXPERIMENTAL> and might change without warning!
+Raise a L<Mojo::Exception>, if the class does not exist yet (classes are checked for a C<new> method), one is created
+as a L<Mojo::Exception> subclass on demand. Note that this function is B<EXPERIMENTAL> and might change without
+warning!
 
 =head1 ATTRIBUTES
 
@@ -320,21 +314,20 @@ Exception message, defaults to C<Exception!>.
   my $bool = $e->verbose;
   $e       = $e->verbose($bool);
 
-Show more information with L</"to_string">, such as L</"frames">, defaults to
-the value of the C<MOJO_EXCEPTION_VERBOSE> environment variable.
+Show more information with L</"to_string">, such as L</"frames">, defaults to the value of the
+C<MOJO_EXCEPTION_VERBOSE> environment variable.
 
 =head1 METHODS
 
-L<Mojo::Exception> inherits all methods from L<Mojo::Base> and implements the
-following new ones.
+L<Mojo::Exception> inherits all methods from L<Mojo::Base> and implements the following new ones.
 
 =head2 inspect
 
   $e = $e->inspect;
   $e = $e->inspect($source1, $source2);
 
-Inspect L</"message">, L</"frames"> and optional additional sources to fill
-L</"lines_before">, L</"line"> and L</"lines_after"> with context information.
+Inspect L</"message">, L</"frames"> and optional additional sources to fill L</"lines_before">, L</"line"> and
+L</"lines_after"> with context information.
 
 =head2 new
 
@@ -347,9 +340,8 @@ Construct a new L<Mojo::Exception> object and assign L</"message"> if necessary.
 
   my $str = $e->to_string;
 
-Render exception. Note that the output format may change as more features are
-added, only the error message at the beginning is guaranteed not to be modified
-to allow regex matching.
+Render exception. Note that the output format may change as more features are added, only the error message at the
+beginning is guaranteed not to be modified to allow regex matching.
 
 =head2 throw
 
@@ -365,8 +357,7 @@ Throw exception from the current execution context.
   $e = $e->trace;
   $e = $e->trace($skip);
 
-Generate stack trace and store all L</"frames">, defaults to skipping C<1> call
-frame.
+Generate stack trace and store all L</"frames">, defaults to skipping C<1> call frame.
 
   # Skip 3 call frames
   $e->trace(3);
