@@ -51,8 +51,7 @@ sub start {
   # Resume
   return unless $self->{handle};
   my $reactor = $self->reactor;
-  return $reactor->watch($self->{handle}, 1, $self->is_writing)
-    if delete $self->{paused};
+  return $reactor->watch($self->{handle}, 1, $self->is_writing) if delete $self->{paused};
 
   weaken $self;
   my $cb = sub { pop() ? $self->_write : $self->_read };
@@ -67,8 +66,7 @@ sub steal_handle {
 
 sub stop {
   my $self = shift;
-  $self->reactor->watch($self->{handle}, 0, $self->is_writing)
-    if $self->{handle} && !$self->{paused}++;
+  $self->reactor->watch($self->{handle}, 0, $self->is_writing) if $self->{handle} && !$self->{paused}++;
 }
 
 sub timeout {
@@ -79,8 +77,8 @@ sub timeout {
 
   my $reactor = $self->reactor;
   if ($self->{timer}) {
-    if (!$self->{timeout}) { $reactor->remove(delete $self->{timer}) }
-    else                   { $reactor->again($self->{timer}, $self->{timeout}) }
+    if   (!$self->{timeout}) { $reactor->remove(delete $self->{timer}) }
+    else                     { $reactor->again($self->{timer}, $self->{timeout}) }
   }
   elsif ($self->{timeout}) {
     weaken $self;
@@ -102,8 +100,7 @@ sub write {
   $self->{buffer} .= $chunk;
   if    ($cb)                     { $self->once(drain => $cb) }
   elsif (!length $self->{buffer}) { return $self }
-  $self->reactor->watch($self->{handle}, !$self->{paused}, 1)
-    if $self->{handle};
+  $self->reactor->watch($self->{handle}, !$self->{paused}, 1) if $self->{handle};
 
   return $self;
 }
@@ -131,8 +128,7 @@ sub _write {
   # Handle errors only when reading (to avoid timing problems)
   my $handle = $self->{handle};
   if (length $self->{buffer}) {
-    return undef
-      unless defined(my $written = $handle->syswrite($self->{buffer}));
+    return undef unless defined(my $written = $handle->syswrite($self->{buffer}));
     $self->{written} += $written;
     $self->emit(write => substr($self->{buffer}, 0, $written, ''))->_again;
   }
@@ -184,8 +180,7 @@ L<Mojo::IOLoop::Stream> is a container for I/O streams used by L<Mojo::IOLoop>.
 
 =head1 EVENTS
 
-L<Mojo::IOLoop::Stream> inherits all events from L<Mojo::EventEmitter> and can
-emit the following new ones.
+L<Mojo::IOLoop::Stream> inherits all events from L<Mojo::EventEmitter> and can emit the following new ones.
 
 =head2 close
 
@@ -230,8 +225,7 @@ Emitted if new data arrives on the stream.
     ...
   });
 
-Emitted if the stream has been inactive for too long and will get closed
-automatically.
+Emitted if the stream has been inactive for too long and will get closed automatically.
 
 =head2 write
 
@@ -251,21 +245,19 @@ L<Mojo::IOLoop::Stream> implements the following attributes.
   my $size = $msg->high_water_mark;
   $msg     = $msg->high_water_mark(1024);
 
-Maximum size of L</"write"> buffer in bytes before L</"can_write"> returns
-false, defaults to C<1048576> (1MiB).
+Maximum size of L</"write"> buffer in bytes before L</"can_write"> returns false, defaults to C<1048576> (1MiB).
 
 =head2 reactor
 
   my $reactor = $stream->reactor;
   $stream     = $stream->reactor(Mojo::Reactor::Poll->new);
 
-Low-level event reactor, defaults to the C<reactor> attribute value of the
-global L<Mojo::IOLoop> singleton. Note that this attribute is weakened.
+Low-level event reactor, defaults to the C<reactor> attribute value of the global L<Mojo::IOLoop> singleton. Note that
+this attribute is weakened.
 
 =head1 METHODS
 
-L<Mojo::IOLoop::Stream> inherits all methods from L<Mojo::EventEmitter> and
-implements the following new ones.
+L<Mojo::IOLoop::Stream> inherits all methods from L<Mojo::EventEmitter> and implements the following new ones.
 
 =head2 bytes_read
 
@@ -277,8 +269,7 @@ Number of bytes received.
 
   my $num = $stream->bytes_waiting;
 
-Number of bytes that have been enqueued with L</"write"> and are waiting to be
-written.
+Number of bytes that have been enqueued with L</"write"> and are waiting to be written.
 
 =head2 bytes_written
 
@@ -308,15 +299,13 @@ Close stream gracefully.
 
   my $handle = $stream->handle;
 
-Get handle for stream, usually an L<IO::Socket::IP> or L<IO::Socket::SSL>
-object.
+Get handle for stream, usually an L<IO::Socket::IP> or L<IO::Socket::SSL> object.
 
 =head2 is_readable
 
   my $bool = $stream->is_readable;
 
-Quick non-blocking check if stream is readable, useful for identifying tainted
-sockets.
+Quick non-blocking check if stream is readable, useful for identifying tainted sockets.
 
 =head2 is_writing
 
@@ -353,17 +342,16 @@ Stop watching for new data on the stream.
   my $timeout = $stream->timeout;
   $stream     = $stream->timeout(45);
 
-Maximum amount of time in seconds stream can be inactive before getting closed
-automatically, defaults to C<15>. Setting the value to C<0> will allow this
-stream to be inactive indefinitely.
+Maximum amount of time in seconds stream can be inactive before getting closed automatically, defaults to C<15>.
+Setting the value to C<0> will allow this stream to be inactive indefinitely.
 
 =head2 write
 
   $stream = $stream->write($bytes);
   $stream = $stream->write($bytes => sub {...});
 
-Enqueue data to be written to the stream as soon as possible, the optional drain
-callback will be executed once all data has been written.
+Enqueue data to be written to the stream as soon as possible, the optional drain callback will be executed once all
+data has been written.
 
 =head1 SEE ALSO
 
