@@ -25,8 +25,7 @@ sub body {
   return $content->is_multipart ? '' : $content->asset->slurp unless @_;
 
   # Set (multipart content needs to be downgraded)
-  $content = $self->content(Mojo::Content::Single->new)->content
-    if $content->is_multipart;
+  $content = $self->content(Mojo::Content::Single->new)->content if $content->is_multipart;
   $content->asset(Mojo::Asset::Memory->new->add_chunk(@_));
 
   return $self;
@@ -97,10 +96,10 @@ sub fix_headers {
   # Content-Length or Connection (unless chunked transfer encoding is used)
   my $content = $self->content;
   my $headers = $content->headers;
-  if ($content->is_multipart) { $headers->remove('Content-Length') }
+  if    ($content->is_multipart)                           { $headers->remove('Content-Length') }
   elsif ($content->is_chunked || $headers->content_length) { return $self }
-  if   ($content->is_dynamic) { $headers->connection('close') }
-  else                        { $headers->content_length($self->body_size) }
+  if    ($content->is_dynamic)                             { $headers->connection('close') }
+  else                                                     { $headers->content_length($self->body_size) }
 
   return $self;
 }
@@ -154,29 +153,24 @@ sub parse {
     # Check start-line size
     my $len = index $self->{buffer}, "\x0a";
     $len = length $self->{buffer} if $len < 0;
-    return $self->_limit('Maximum start-line size exceeded')
-      if $len > $self->max_line_size;
+    return $self->_limit('Maximum start-line size exceeded') if $len > $self->max_line_size;
 
     $self->{state} = 'content' if $self->extract_start_line(\$self->{buffer});
   }
 
   # Content
   my $state = $self->{state} // '';
-  $self->content($self->content->parse(delete $self->{buffer}))
-    if $state eq 'content' || $state eq 'finished';
+  $self->content($self->content->parse(delete $self->{buffer})) if $state eq 'content' || $state eq 'finished';
 
   # Check message size
   my $max = $self->max_message_size;
-  return $self->_limit('Maximum message size exceeded')
-    if $max && $max < $self->{raw_size};
+  return $self->_limit('Maximum message size exceeded') if $max && $max < $self->{raw_size};
 
   # Check header size
-  return $self->_limit('Maximum header size exceeded')
-    if $self->headers->is_limit_exceeded;
+  return $self->_limit('Maximum header size exceeded') if $self->headers->is_limit_exceeded;
 
   # Check buffer size
-  return $self->_limit('Maximum buffer size exceeded')
-    if $self->content->is_limit_exceeded;
+  return $self->_limit('Maximum buffer size exceeded') if $self->content->is_limit_exceeded;
 
   return $self->emit('progress')->content->is_finished ? $self->finish : $self;
 }
@@ -313,16 +307,13 @@ Mojo::Message - HTTP message base class
 
 =head1 DESCRIPTION
 
-L<Mojo::Message> is an abstract base class for HTTP message containers, based on
-L<RFC 7230|http://tools.ietf.org/html/rfc7230>,
-L<RFC 7231|http://tools.ietf.org/html/rfc7231> and
-L<RFC 2388|http://tools.ietf.org/html/rfc2388>, like L<Mojo::Message::Request>
-and L<Mojo::Message::Response>.
+L<Mojo::Message> is an abstract base class for HTTP message containers, based on L<RFC
+7230|http://tools.ietf.org/html/rfc7230>, L<RFC 7231|http://tools.ietf.org/html/rfc7231> and L<RFC
+2388|http://tools.ietf.org/html/rfc2388>, like L<Mojo::Message::Request> and L<Mojo::Message::Response>.
 
 =head1 EVENTS
 
-L<Mojo::Message> inherits all events from L<Mojo::EventEmitter> and can emit
-the following new ones.
+L<Mojo::Message> inherits all events from L<Mojo::EventEmitter> and can emit the following new ones.
 
 =head2 finish
 
@@ -378,26 +369,24 @@ Message content, defaults to a L<Mojo::Content::Single> object.
   my $charset = $msg->default_charset;
   $msg        = $msg->default_charset('UTF-8');
 
-Default charset used by L</"text"> and to extract data from
-C<application/x-www-form-urlencoded> or C<multipart/form-data> message body,
-defaults to C<UTF-8>.
+Default charset used by L</"text"> and to extract data from C<application/x-www-form-urlencoded> or
+C<multipart/form-data> message body, defaults to C<UTF-8>.
 
 =head2 max_line_size
 
   my $size = $msg->max_line_size;
   $msg     = $msg->max_line_size(1024);
 
-Maximum start-line size in bytes, defaults to the value of the
-C<MOJO_MAX_LINE_SIZE> environment variable or C<8192> (8KiB).
+Maximum start-line size in bytes, defaults to the value of the C<MOJO_MAX_LINE_SIZE> environment variable or C<8192>
+(8KiB).
 
 =head2 max_message_size
 
   my $size = $msg->max_message_size;
   $msg     = $msg->max_message_size(1024);
 
-Maximum message size in bytes, defaults to the value of the
-C<MOJO_MAX_MESSAGE_SIZE> environment variable or C<16777216> (16MiB). Setting
-the value to C<0> will allow messages of indefinite size.
+Maximum message size in bytes, defaults to the value of the C<MOJO_MAX_MESSAGE_SIZE> environment variable or
+C<16777216> (16MiB). Setting the value to C<0> will allow messages of indefinite size.
 
 =head2 version
 
@@ -408,8 +397,7 @@ HTTP version of message, defaults to C<1.1>.
 
 =head1 METHODS
 
-L<Mojo::Message> inherits all methods from L<Mojo::EventEmitter> and implements
-the following new ones.
+L<Mojo::Message> inherits all methods from L<Mojo::EventEmitter> and implements the following new ones.
 
 =head2 body
 
@@ -422,13 +410,11 @@ Slurp or replace L</"content">.
 
   my $params = $msg->body_params;
 
-C<POST> parameters extracted from C<application/x-www-form-urlencoded> or
-C<multipart/form-data> message body, usually a L<Mojo::Parameters> object. Note
-that this method caches all data, so it should not be called before the entire
-message body has been received. Parts of the message body need to be loaded
-into memory to parse C<POST> parameters, so you have to make sure it is not
-excessively large. There's a 16MiB limit for requests and a 2GiB limit for
-responses by default.
+C<POST> parameters extracted from C<application/x-www-form-urlencoded> or C<multipart/form-data> message body, usually
+a L<Mojo::Parameters> object. Note that this method caches all data, so it should not be called before the entire
+message body has been received. Parts of the message body need to be loaded into memory to parse C<POST> parameters, so
+you have to make sure it is not excessively large. There's a 16MiB limit for requests and a 2GiB limit for responses by
+default.
 
   # Get POST parameter names and values
   my $hash = $msg->body_params->to_hash;
@@ -461,11 +447,9 @@ Render start-line with L</"get_start_line_chunk">.
 
   my $cookie = $msg->cookie('foo');
 
-Access message cookies, usually L<Mojo::Cookie::Request> or
-L<Mojo::Cookie::Response> objects. If there are multiple cookies sharing the
-same name, and you want to access more than just the last one, you can use
-L</"every_cookie">. Note that this method caches all data, so it should not be
-called before all headers have been received.
+Access message cookies, usually L<Mojo::Cookie::Request> or L<Mojo::Cookie::Response> objects. If there are multiple
+cookies sharing the same name, and you want to access more than just the last one, you can use L</"every_cookie">. Note
+that this method caches all data, so it should not be called before all headers have been received.
 
   # Get cookie value
   say $msg->cookie('foo')->value;
@@ -481,13 +465,11 @@ Access message cookies. Meant to be overloaded in a subclass.
   my $dom        = $msg->dom;
   my $collection = $msg->dom('a[href]');
 
-Retrieve message body from L</"text"> and turn it into a L<Mojo::DOM> object,
-an optional selector can be used to call the method L<Mojo::DOM/"find"> on it
-right away, which then returns a L<Mojo::Collection> object. Note that this
-method caches all data, so it should not be called before the entire message
-body has been received. The whole message body needs to be loaded into memory
-to parse it, so you have to make sure it is not excessively large. There's a
-16MiB limit for requests and a 2GiB limit for responses by default.
+Retrieve message body from L</"text"> and turn it into a L<Mojo::DOM> object, an optional selector can be used to call
+the method L<Mojo::DOM/"find"> on it right away, which then returns a L<Mojo::Collection> object. Note that this method
+caches all data, so it should not be called before the entire message body has been received. The whole message body
+needs to be loaded into memory to parse it, so you have to make sure it is not excessively large. There's a 16MiB limit
+for requests and a 2GiB limit for responses by default.
 
   # Perform "find" right away
   say $msg->dom('h1, h2, h3')->map('text')->join("\n");
@@ -501,8 +483,7 @@ to parse it, so you have to make sure it is not excessively large. There's a
   my $err = $msg->error;
   $msg    = $msg->error({message => 'Parser error'});
 
-Get or set message error, an C<undef> return value indicates that there is no
-error.
+Get or set message error, an C<undef> return value indicates that there is no error.
 
   # Connection or parser error
   $msg->error({message => 'Connection refused'});
@@ -514,8 +495,7 @@ error.
 
   my $cookies = $msg->every_cookie('foo');
 
-Similar to L</"cookie">, but returns all message cookies sharing the same name
-as an array reference.
+Similar to L</"cookie">, but returns all message cookies sharing the same name as an array reference.
 
   # Get first cookie value
   say $msg->every_cookie('foo')->[0]->value;
@@ -524,8 +504,7 @@ as an array reference.
 
   my $uploads = $msg->every_upload('foo');
 
-Similar to L</"upload">, but returns all file uploads sharing the same name as
-an array reference.
+Similar to L</"upload">, but returns all file uploads sharing the same name as an array reference.
 
   # Get content of first uploaded file
   say $msg->every_upload('foo')->[0]->asset->slurp;
@@ -552,23 +531,20 @@ Make sure message has all required headers.
 
   my $bytes = $msg->get_body_chunk($offset);
 
-Get a chunk of body data starting from a specific position. Note that it might
-not be possible to get the same chunk twice if content was generated
-dynamically.
+Get a chunk of body data starting from a specific position. Note that it might not be possible to get the same chunk
+twice if content was generated dynamically.
 
 =head2 get_header_chunk
 
   my $bytes = $msg->get_header_chunk($offset);
 
-Get a chunk of header data, starting from a specific position. Note that this
-method finalizes the message.
+Get a chunk of header data, starting from a specific position. Note that this method finalizes the message.
 
 =head2 get_start_line_chunk
 
   my $bytes = $msg->get_start_line_chunk($offset);
 
-Get a chunk of start-line data starting from a specific position. Meant to be
-overloaded in a subclass.
+Get a chunk of start-line data starting from a specific position. Meant to be overloaded in a subclass.
 
 =head2 header_size
 
@@ -595,22 +571,19 @@ Check if message parser/generator is finished.
 
   my $bool = $msg->is_limit_exceeded;
 
-Check if message has exceeded L</"max_line_size">, L</"max_message_size">,
-L<Mojo::Content/"max_buffer_size"> or L<Mojo::Headers/"max_line_size">.
+Check if message has exceeded L</"max_line_size">, L</"max_message_size">, L<Mojo::Content/"max_buffer_size"> or
+L<Mojo::Headers/"max_line_size">.
 
 =head2 json
 
   my $value = $msg->json;
   my $value = $msg->json('/foo/bar');
 
-Decode JSON message body directly using L<Mojo::JSON> if possible, an C<undef>
-return value indicates a bare C<null> or that decoding failed. An optional JSON
-Pointer can be used to extract a specific value with L<Mojo::JSON::Pointer>.
-Note that this method caches all data, so it should not be called before the
-entire message body has been received. The whole message body needs to be
-loaded into memory to parse it, so you have to make sure it is not excessively
-large. There's a 16MiB limit for requests and a 2GiB limit for responses by
-default.
+Decode JSON message body directly using L<Mojo::JSON> if possible, an C<undef> return value indicates a bare C<null> or
+that decoding failed. An optional JSON Pointer can be used to extract a specific value with L<Mojo::JSON::Pointer>.
+Note that this method caches all data, so it should not be called before the entire message body has been received. The
+whole message body needs to be loaded into memory to parse it, so you have to make sure it is not excessively large.
+There's a 16MiB limit for requests and a 2GiB limit for responses by default.
 
   # Extract JSON values
   say $msg->json->{foo}{bar}[23];
@@ -638,26 +611,22 @@ Size of the start-line in bytes. Meant to be overloaded in a subclass.
 
   my $str = $msg->text;
 
-Retrieve L</"body"> and try to decode it with L<Mojo::Content/"charset"> or
-L</"default_charset">.
+Retrieve L</"body"> and try to decode it with L<Mojo::Content/"charset"> or L</"default_charset">.
 
 =head2 to_string
 
   my $str = $msg->to_string;
 
-Render whole message. Note that this method finalizes the message, and that it
-might not be possible to render the same message twice if content was generated
-dynamically.
+Render whole message. Note that this method finalizes the message, and that it might not be possible to render the same
+message twice if content was generated dynamically.
 
 =head2 upload
 
   my $upload = $msg->upload('foo');
 
-Access C<multipart/form-data> file uploads, usually L<Mojo::Upload> objects. If
-there are multiple uploads sharing the same name, and you want to access more
-than just the last one, you can use L</"every_upload">. Note that this method
-caches all data, so it should not be called before the entire message body has
-been received.
+Access C<multipart/form-data> file uploads, usually L<Mojo::Upload> objects. If there are multiple uploads sharing the
+same name, and you want to access more than just the last one, you can use L</"every_upload">. Note that this method
+caches all data, so it should not be called before the entire message body has been received.
 
   # Get content of uploaded file
   say $msg->upload('foo')->asset->slurp;
