@@ -27,8 +27,8 @@ has max_connections => 5;
 has max_redirects   => sub { $ENV{MOJO_MAX_REDIRECTS} || 0 };
 has proxy           => sub { Mojo::UserAgent::Proxy->new };
 has request_timeout => sub { $ENV{MOJO_REQUEST_TIMEOUT} // 0 };
-has server     => sub { Mojo::UserAgent::Server->new(ioloop => shift->ioloop) };
-has transactor => sub { Mojo::UserAgent::Transactor->new };
+has server          => sub { Mojo::UserAgent::Server->new(ioloop => shift->ioloop) };
+has transactor      => sub { Mojo::UserAgent::Transactor->new };
 
 # Common HTTP methods
 for my $name (qw(DELETE GET HEAD OPTIONS PATCH POST PUT)) {
@@ -149,12 +149,10 @@ sub _connect_proxy {
 
       # Real transaction
       $old->previous($tx)->req->via_proxy(0);
-      my $c = $self->{connections}{$id}
-        = {cb => $cb, ioloop => $loop, tx => $old};
+      my $c = $self->{connections}{$id} = {cb => $cb, ioloop => $loop, tx => $old};
 
       # CONNECT failed
-      return $self->_error($id, 'Proxy connection failed')
-        if $tx->error || !$tx->res->is_success || !$tx->keep_alive;
+      return $self->_error($id, 'Proxy connection failed') if $tx->error || !$tx->res->is_success || !$tx->keep_alive;
 
       # Start real transaction without TLS upgrade
       return $self->_process($id) unless $tx->req->url->protocol eq 'https';
@@ -186,8 +184,7 @@ sub _connection {
   if (my $id = $self->_connect_proxy($loop, $tx, $cb)) { return $id }
 
   # New connection
-  $tx->res->error({message => "Unsupported protocol: $proto"})
-    and return $loop->next_tick(sub { $self->$cb($tx) })
+  $tx->res->error({message => "Unsupported protocol: $proto"}) and return $loop->next_tick(sub { $self->$cb($tx) })
     unless $proto eq 'http' || $proto eq 'https' || $proto eq 'http+unix';
   $id = $self->_connect($loop, $tx);
   warn "-- Connect $id ($proto://$host:$port)\n" if DEBUG;
@@ -300,8 +297,7 @@ sub _reuse {
   my $c   = $self->{connections}{$id};
   my $tx  = delete $c->{tx};
   my $max = $self->max_connections;
-  return $self->_remove($id)
-    if $close || !$tx || !$max || !$tx->keep_alive || $tx->error;
+  return $self->_remove($id) if $close || !$tx || !$max || !$tx->keep_alive || $tx->error;
 
   # Keep connection alive
   my $queue = $self->{queue}{$c->{ioloop}} ||= [];
@@ -331,8 +327,7 @@ sub _start {
 
   if (my $t = $self->request_timeout) {
     weaken $self;
-    $self->{connections}{$id}{timeout}
-      ||= $loop->timer($t => sub { $self->_error($id, 'Request timeout') });
+    $self->{connections}{$id}{timeout} ||= $loop->timer($t => sub { $self->_error($id, 'Request timeout') });
   }
 
   return $id;
@@ -382,8 +377,7 @@ Mojo::UserAgent - Non-blocking I/O HTTP and WebSocket user agent
   say $ua->get('www.perl.org')->result->dom->at('title')->text;
 
   # Scrape the latest headlines from a news site
-  say $ua->get('blogs.perl.org')
-    ->result->dom->find('h2 > a')->map('text')->join("\n");
+  say $ua->get('blogs.perl.org')->result->dom->find('h2 > a')->map('text')->join("\n");
 
   # IPv6 PUT request with Content-Type header and content
   my $tx = $ua->put('[::1]:3000' => {'Content-Type' => 'text/plain'} => 'Hi!');
@@ -393,16 +387,14 @@ Mojo::UserAgent - Non-blocking I/O HTTP and WebSocket user agent
   my $value = $ua->get($url)->result->json;
 
   # JSON POST (application/json) with TLS certificate authentication
-  my $tx = $ua->cert('tls.crt')->key('tls.key')
-    ->post('https://example.com' => json => {top => 'secret'});
+  my $tx = $ua->cert('tls.crt')->key('tls.key')->post('https://example.com' => json => {top => 'secret'});
 
   # Form POST (application/x-www-form-urlencoded)
   my $tx = $ua->post('https://metacpan.org/search' => form => {q => 'mojo'});
 
   # Search DuckDuckGo anonymously through Tor
   $ua->proxy->http('socks://127.0.0.1:9050');
-  say $ua->get('api.3g2upl4pq6kufc4m.onion/?q=mojolicious&format=json')
-    ->result->json('/Abstract');
+  say $ua->get('api.3g2upl4pq6kufc4m.onion/?q=mojolicious&format=json')->result->json('/Abstract');
 
   # GET request via UNIX domain socket "/tmp/myapp.sock" (percent encoded slash)
   say $ua->get('http+unix://%2Ftmp%2Fmyapp.sock/perldoc')->result->body;
@@ -443,28 +435,23 @@ Mojo::UserAgent - Non-blocking I/O HTTP and WebSocket user agent
 
 =head1 DESCRIPTION
 
-L<Mojo::UserAgent> is a full featured non-blocking I/O HTTP and WebSocket user
-agent, with IPv6, TLS, SNI, IDNA, HTTP/SOCKS5 proxy, UNIX domain socket, Comet
-(long polling), Promises/A+, keep-alive, connection pooling, timeout, cookie,
-multipart, gzip compression and multiple event loop support.
+L<Mojo::UserAgent> is a full featured non-blocking I/O HTTP and WebSocket user agent, with IPv6, TLS, SNI, IDNA,
+HTTP/SOCKS5 proxy, UNIX domain socket, Comet (long polling), Promises/A+, keep-alive, connection pooling, timeout,
+cookie, multipart, gzip compression and multiple event loop support.
 
-All connections will be reset automatically if a new process has been forked,
-this allows multiple processes to share the same L<Mojo::UserAgent> object
-safely.
+All connections will be reset automatically if a new process has been forked, this allows multiple processes to share
+the same L<Mojo::UserAgent> object safely.
 
-For better scalability (epoll, kqueue) and to provide non-blocking name
-resolution, SOCKS5 as well as TLS support, the optional modules L<EV> (4.32+),
-L<Net::DNS::Native> (0.15+), L<IO::Socket::Socks> (0.64+) and
-L<IO::Socket::SSL> (2.009+) will be used automatically if possible. Individual
-features can also be disabled with the C<MOJO_NO_NNR>, C<MOJO_NO_SOCKS> and
-C<MOJO_NO_TLS> environment variables.
+For better scalability (epoll, kqueue) and to provide non-blocking name resolution, SOCKS5 as well as TLS support, the
+optional modules L<EV> (4.32+), L<Net::DNS::Native> (0.15+), L<IO::Socket::Socks> (0.64+) and L<IO::Socket::SSL>
+(2.009+) will be used automatically if possible. Individual features can also be disabled with the C<MOJO_NO_NNR>,
+C<MOJO_NO_SOCKS> and C<MOJO_NO_TLS> environment variables.
 
 See L<Mojolicious::Guides::Cookbook/"USER AGENT"> for more.
 
 =head1 EVENTS
 
-L<Mojo::UserAgent> inherits all events from L<Mojo::EventEmitter> and can emit
-the following new ones.
+L<Mojo::UserAgent> inherits all events from L<Mojo::EventEmitter> and can emit the following new ones.
 
 =head2 prepare
 
@@ -473,14 +460,12 @@ the following new ones.
     ...
   });
 
-Emitted whenever a new transaction is being prepared, before relative URLs are
-rewritten and cookies added. This includes automatically prepared proxy
-C<CONNECT> requests and followed redirects.
+Emitted whenever a new transaction is being prepared, before relative URLs are rewritten and cookies added. This
+includes automatically prepared proxy C<CONNECT> requests and followed redirects.
 
   $ua->on(prepare => sub {
     my ($ua, $tx) = @_;
-    $tx->req->url(Mojo::URL->new('/mock-mojolicious'))
-      if $tx->req->url->host eq 'mojolicious.org';
+    $tx->req->url(Mojo::URL->new('/mock-mojolicious')) if $tx->req->url->host eq 'mojolicious.org';
   });
 
 =head2 start
@@ -490,8 +475,8 @@ C<CONNECT> requests and followed redirects.
     ...
   });
 
-Emitted whenever a new transaction is about to start. This includes
-automatically prepared proxy C<CONNECT> requests and followed redirects.
+Emitted whenever a new transaction is about to start. This includes automatically prepared proxy C<CONNECT> requests
+and followed redirects.
 
   $ua->on(start => sub {
     my ($ua, $tx) = @_;
@@ -507,37 +492,33 @@ L<Mojo::UserAgent> implements the following attributes.
   my $ca = $ua->ca;
   $ua    = $ua->ca('/etc/tls/ca.crt');
 
-Path to TLS certificate authority file used to verify the peer certificate,
-defaults to the value of the C<MOJO_CA_FILE> environment variable.
+Path to TLS certificate authority file used to verify the peer certificate, defaults to the value of the
+C<MOJO_CA_FILE> environment variable.
 
   # Show certificate authorities for debugging
-  IO::Socket::SSL::set_defaults(
-    SSL_verify_callback => sub { say "Authority: $_[2]" and return $_[0] });
+  IO::Socket::SSL::set_defaults(SSL_verify_callback => sub { say "Authority: $_[2]" and return $_[0] });
 
 =head2 cert
 
   my $cert = $ua->cert;
   $ua      = $ua->cert('/etc/tls/client.crt');
 
-Path to TLS certificate file, defaults to the value of the C<MOJO_CERT_FILE>
-environment variable.
+Path to TLS certificate file, defaults to the value of the C<MOJO_CERT_FILE> environment variable.
 
 =head2 connect_timeout
 
   my $timeout = $ua->connect_timeout;
   $ua         = $ua->connect_timeout(5);
 
-Maximum amount of time in seconds establishing a connection may take before
-getting canceled, defaults to the value of the C<MOJO_CONNECT_TIMEOUT>
-environment variable or C<10>.
+Maximum amount of time in seconds establishing a connection may take before getting canceled, defaults to the value of
+the C<MOJO_CONNECT_TIMEOUT> environment variable or C<10>.
 
 =head2 cookie_jar
 
   my $cookie_jar = $ua->cookie_jar;
   $ua            = $ua->cookie_jar(Mojo::UserAgent::CookieJar->new);
 
-Cookie jar to use for requests performed by this user agent, defaults to a
-L<Mojo::UserAgent::CookieJar> object.
+Cookie jar to use for requests performed by this user agent, defaults to a L<Mojo::UserAgent::CookieJar> object.
 
   # Ignore all cookies
   $ua->cookie_jar->ignore(sub { 1 });
@@ -565,9 +546,8 @@ L<Mojo::UserAgent::CookieJar> object.
   my $timeout = $ua->inactivity_timeout;
   $ua         = $ua->inactivity_timeout(15);
 
-Maximum amount of time in seconds a connection can be inactive before getting
-closed, defaults to the value of the C<MOJO_INACTIVITY_TIMEOUT> environment
-variable or C<40>. Setting the value to C<0> will allow connections to be
+Maximum amount of time in seconds a connection can be inactive before getting closed, defaults to the value of the
+C<MOJO_INACTIVITY_TIMEOUT> environment variable or C<40>. Setting the value to C<0> will allow connections to be
 inactive indefinitely.
 
 =head2 insecure
@@ -575,8 +555,8 @@ inactive indefinitely.
   my $bool = $ua->insecure;
   $ua      = $ua->insecure($bool);
 
-Do not require a valid TLS certificate to access HTTPS/WSS sites, defaults to
-the value of the C<MOJO_INSECURE> environment variable.
+Do not require a valid TLS certificate to access HTTPS/WSS sites, defaults to the value of the C<MOJO_INSECURE>
+environment variable.
 
   # Disable TLS certificate verification for testing
   say $ua->insecure(1)->get('https://127.0.0.1:3000')->result->code;
@@ -586,16 +566,14 @@ the value of the C<MOJO_INSECURE> environment variable.
   my $loop = $ua->ioloop;
   $ua      = $ua->ioloop(Mojo::IOLoop->new);
 
-Event loop object to use for blocking I/O operations, defaults to a
-L<Mojo::IOLoop> object.
+Event loop object to use for blocking I/O operations, defaults to a L<Mojo::IOLoop> object.
 
 =head2 key
 
   my $key = $ua->key;
   $ua     = $ua->key('/etc/tls/client.crt');
 
-Path to TLS key file, defaults to the value of the C<MOJO_KEY_FILE> environment
-variable.
+Path to TLS key file, defaults to the value of the C<MOJO_KEY_FILE> environment variable.
 
 =head2 local_address
 
@@ -609,30 +587,26 @@ Local address to bind to.
   my $max = $ua->max_connections;
   $ua     = $ua->max_connections(5);
 
-Maximum number of keep-alive connections that the user agent will retain before
-it starts closing the oldest ones, defaults to C<5>. Setting the value to C<0>
-will prevent any connections from being kept alive.
+Maximum number of keep-alive connections that the user agent will retain before it starts closing the oldest ones,
+defaults to C<5>. Setting the value to C<0> will prevent any connections from being kept alive.
 
 =head2 max_redirects
 
   my $max = $ua->max_redirects;
   $ua     = $ua->max_redirects(3);
 
-Maximum number of redirects the user agent will follow before it fails,
-defaults to the value of the C<MOJO_MAX_REDIRECTS> environment variable or
-C<0>.
+Maximum number of redirects the user agent will follow before it fails, defaults to the value of the
+C<MOJO_MAX_REDIRECTS> environment variable or C<0>.
 
 =head2 max_response_size
 
   my $max = $ua->max_response_size;
   $ua     = $ua->max_response_size(16777216);
 
-Maximum response size in bytes, defaults to the value of
-L<Mojo::Message::Response/"max_message_size">. Setting the value to C<0> will
-allow responses of indefinite size. Note that increasing this value can also
-drastically increase memory usage, should you for example attempt to parse an
-excessively large response body with the methods L<Mojo::Message/"dom"> or
-L<Mojo::Message/"json">.
+Maximum response size in bytes, defaults to the value of L<Mojo::Message::Response/"max_message_size">. Setting the
+value to C<0> will allow responses of indefinite size. Note that increasing this value can also drastically increase
+memory usage, should you for example attempt to parse an excessively large response body with the methods
+L<Mojo::Message/"dom"> or L<Mojo::Message/"json">.
 
 =head2 proxy
 
@@ -651,19 +625,17 @@ Proxy manager, defaults to a L<Mojo::UserAgent::Proxy> object.
   $ua->proxy->http('socks://127.0.0.1:9050')->https('socks://127.0.0.1:9050');
 
   # Manually configure UNIX domain socket (using CONNECT for HTTPS/WebSockets)
-  $ua->proxy->http('http+unix://%2Ftmp%2Fproxy.sock')
-    ->https('http+unix://%2Ftmp%2Fproxy.sock');
+  $ua->proxy->http('http+unix://%2Ftmp%2Fproxy.sock') ->https('http+unix://%2Ftmp%2Fproxy.sock');
 
 =head2 request_timeout
 
   my $timeout = $ua->request_timeout;
   $ua         = $ua->request_timeout(5);
 
-Maximum amount of time in seconds establishing a connection, sending the
-request and receiving a whole response may take before getting canceled,
-defaults to the value of the C<MOJO_REQUEST_TIMEOUT> environment variable or
-C<0>. Setting the value to C<0> will allow the user agent to wait indefinitely.
-The timeout will reset for every followed redirect.
+Maximum amount of time in seconds establishing a connection, sending the request and receiving a whole response may
+take before getting canceled, defaults to the value of the C<MOJO_REQUEST_TIMEOUT> environment variable or C<0>.
+Setting the value to C<0> will allow the user agent to wait indefinitely. The timeout will reset for every followed
+redirect.
 
   # Total limit of 5 seconds, of which 3 seconds may be spent connecting
   $ua->max_redirects(0)->connect_timeout(3)->request_timeout(5);
@@ -673,8 +645,7 @@ The timeout will reset for every followed redirect.
   my $server = $ua->server;
   $ua        = $ua->server(Mojo::UserAgent::Server->new);
 
-Application server relative URLs will be processed with, defaults to a
-L<Mojo::UserAgent::Server> object.
+Application server relative URLs will be processed with, defaults to a L<Mojo::UserAgent::Server> object.
 
   # Mock web service
   $ua->server->app(Mojolicious->new);
@@ -708,21 +679,16 @@ Transaction builder, defaults to a L<Mojo::UserAgent::Transactor> object.
 
 =head1 METHODS
 
-L<Mojo::UserAgent> inherits all methods from L<Mojo::EventEmitter> and
-implements the following new ones.
+L<Mojo::UserAgent> inherits all methods from L<Mojo::EventEmitter> and implements the following new ones.
 
 =head2 build_tx
 
   my $tx = $ua->build_tx(GET => 'example.com');
-  my $tx = $ua->build_tx(
-    PUT => 'http://example.com' => {Accept => '*/*'} => 'Content!');
-  my $tx = $ua->build_tx(
-    PUT => 'http://example.com' => {Accept => '*/*'} => form => {a => 'b'});
-  my $tx = $ua->build_tx(
-    PUT => 'http://example.com' => {Accept => '*/*'} => json => {a => 'b'});
+  my $tx = $ua->build_tx(PUT => 'http://example.com' => {Accept => '*/*'} => 'Content!');
+  my $tx = $ua->build_tx(PUT => 'http://example.com' => {Accept => '*/*'} => form => {a => 'b'});
+  my $tx = $ua->build_tx(PUT => 'http://example.com' => {Accept => '*/*'} => json => {a => 'b'});
 
-Generate L<Mojo::Transaction::HTTP> object with
-L<Mojo::UserAgent::Transactor/"tx">.
+Generate L<Mojo::Transaction::HTTP> object with L<Mojo::UserAgent::Transactor/"tx">.
 
   # Request with custom cookie
   my $tx = $ua->build_tx(GET => 'https://example.com/account');
@@ -746,11 +712,9 @@ L<Mojo::UserAgent::Transactor/"tx">.
 =head2 build_websocket_tx
 
   my $tx = $ua->build_websocket_tx('ws://example.com');
-  my $tx = $ua->build_websocket_tx(
-    'ws://example.com' => {DNT => 1} => ['v1.proto']);
+  my $tx = $ua->build_websocket_tx( 'ws://example.com' => {DNT => 1} => ['v1.proto']);
 
-Generate L<Mojo::Transaction::HTTP> object with
-L<Mojo::UserAgent::Transactor/"websocket">.
+Generate L<Mojo::Transaction::HTTP> object with L<Mojo::UserAgent::Transactor/"websocket">.
 
   # Custom WebSocket handshake with cookie
   my $tx = $ua->build_websocket_tx('wss://example.com/echo');
@@ -771,15 +735,12 @@ L<Mojo::UserAgent::Transactor/"websocket">.
 
   my $tx = $ua->delete('example.com');
   my $tx = $ua->delete('http://example.com' => {Accept => '*/*'} => 'Content!');
-  my $tx = $ua->delete(
-    'http://example.com' => {Accept => '*/*'} => form => {a => 'b'});
-  my $tx = $ua->delete(
-    'http://example.com' => {Accept => '*/*'} => json => {a => 'b'});
+  my $tx = $ua->delete('http://example.com' => {Accept => '*/*'} => form => {a => 'b'});
+  my $tx = $ua->delete('http://example.com' => {Accept => '*/*'} => json => {a => 'b'});
 
-Perform blocking C<DELETE> request and return resulting
-L<Mojo::Transaction::HTTP> object, takes the same arguments as
-L<Mojo::UserAgent::Transactor/"tx"> (except for the C<DELETE> method, which is
-implied). You can also append a callback to perform requests non-blocking.
+Perform blocking C<DELETE> request and return resulting L<Mojo::Transaction::HTTP> object, takes the same arguments as
+L<Mojo::UserAgent::Transactor/"tx"> (except for the C<DELETE> method, which is implied). You can also append a callback
+to perform requests non-blocking.
 
   $ua->delete('http://example.com' => json => {a => 'b'} => sub {
     my ($ua, $tx) = @_;
@@ -791,8 +752,8 @@ implied). You can also append a callback to perform requests non-blocking.
 
   my $promise = $ua->delete_p('http://example.com');
 
-Same as L</"delete">, but performs all requests non-blocking and returns a
-L<Mojo::Promise> object instead of accepting a callback.
+Same as L</"delete">, but performs all requests non-blocking and returns a L<Mojo::Promise> object instead of accepting
+a callback.
 
   $ua->delete_p('http://example.com' => json => {a => 'b'})->then(sub {
     my $tx = shift;
@@ -811,9 +772,8 @@ L<Mojo::Promise> object instead of accepting a callback.
   my $tx = $ua->get(
     'http://example.com' => {Accept => '*/*'} => json => {a => 'b'});
 
-Perform blocking C<GET> request and return resulting L<Mojo::Transaction::HTTP>
-object, takes the same arguments as L<Mojo::UserAgent::Transactor/"tx"> (except
-for the C<GET> method, which is implied). You can also append a callback to
+Perform blocking C<GET> request and return resulting L<Mojo::Transaction::HTTP> object, takes the same arguments as
+L<Mojo::UserAgent::Transactor/"tx"> (except for the C<GET> method, which is implied). You can also append a callback to
 perform requests non-blocking.
 
   $ua->get('http://example.com' => json => {a => 'b'} => sub {
@@ -826,8 +786,8 @@ perform requests non-blocking.
 
   my $promise = $ua->get_p('http://example.com');
 
-Same as L</"get">, but performs all requests non-blocking and returns a
-L<Mojo::Promise> object instead of accepting a callback.
+Same as L</"get">, but performs all requests non-blocking and returns a L<Mojo::Promise> object instead of accepting a
+callback.
 
   $ua->get_p('http://example.com' => json => {a => 'b'})->then(sub {
     my $tx = shift;
@@ -841,15 +801,12 @@ L<Mojo::Promise> object instead of accepting a callback.
 
   my $tx = $ua->head('example.com');
   my $tx = $ua->head('http://example.com' => {Accept => '*/*'} => 'Content!');
-  my $tx = $ua->head(
-    'http://example.com' => {Accept => '*/*'} => form => {a => 'b'});
-  my $tx = $ua->head(
-    'http://example.com' => {Accept => '*/*'} => json => {a => 'b'});
+  my $tx = $ua->head('http://example.com' => {Accept => '*/*'} => form => {a => 'b'});
+  my $tx = $ua->head('http://example.com' => {Accept => '*/*'} => json => {a => 'b'});
 
-Perform blocking C<HEAD> request and return resulting
-L<Mojo::Transaction::HTTP> object, takes the same arguments as
-L<Mojo::UserAgent::Transactor/"tx"> (except for the C<HEAD> method, which is
-implied). You can also append a callback to perform requests non-blocking.
+Perform blocking C<HEAD> request and return resulting L<Mojo::Transaction::HTTP> object, takes the same arguments as
+L<Mojo::UserAgent::Transactor/"tx"> (except for the C<HEAD> method, which is implied). You can also append a callback
+to perform requests non-blocking.
 
   $ua->head('http://example.com' => json => {a => 'b'} => sub {
     my ($ua, $tx) = @_;
@@ -861,8 +818,8 @@ implied). You can also append a callback to perform requests non-blocking.
 
   my $promise = $ua->head_p('http://example.com');
 
-Same as L</"head">, but performs all requests non-blocking and returns a
-L<Mojo::Promise> object instead of accepting a callback.
+Same as L</"head">, but performs all requests non-blocking and returns a L<Mojo::Promise> object instead of accepting a
+callback.
 
   $ua->head_p('http://example.com' => json => {a => 'b'})->then(sub {
     my $tx = shift;
@@ -875,17 +832,13 @@ L<Mojo::Promise> object instead of accepting a callback.
 =head2 options
 
   my $tx = $ua->options('example.com');
-  my $tx = $ua->options(
-    'http://example.com' => {Accept => '*/*'} => 'Content!');
-  my $tx = $ua->options(
-    'http://example.com' => {Accept => '*/*'} => form => {a => 'b'});
-  my $tx = $ua->options(
-    'http://example.com' => {Accept => '*/*'} => json => {a => 'b'});
+  my $tx = $ua->options('http://example.com' => {Accept => '*/*'} => 'Content!');
+  my $tx = $ua->options('http://example.com' => {Accept => '*/*'} => form => {a => 'b'});
+  my $tx = $ua->options('http://example.com' => {Accept => '*/*'} => json => {a => 'b'});
 
-Perform blocking C<OPTIONS> request and return resulting
-L<Mojo::Transaction::HTTP> object, takes the same arguments as
-L<Mojo::UserAgent::Transactor/"tx"> (except for the C<OPTIONS> method, which is
-implied). You can also append a callback to perform requests non-blocking.
+Perform blocking C<OPTIONS> request and return resulting L<Mojo::Transaction::HTTP> object, takes the same arguments as
+L<Mojo::UserAgent::Transactor/"tx"> (except for the C<OPTIONS> method, which is implied). You can also append a
+callback to perform requests non-blocking.
 
   $ua->options('http://example.com' => json => {a => 'b'} => sub {
     my ($ua, $tx) = @_;
@@ -897,8 +850,8 @@ implied). You can also append a callback to perform requests non-blocking.
 
   my $promise = $ua->options_p('http://example.com');
 
-Same as L</"options">, but performs all requests non-blocking and returns a
-L<Mojo::Promise> object instead of accepting a callback.
+Same as L</"options">, but performs all requests non-blocking and returns a L<Mojo::Promise> object instead of
+accepting a callback.
 
   $ua->options_p('http://example.com' => json => {a => 'b'})->then(sub {
     my $tx = shift;
@@ -912,15 +865,12 @@ L<Mojo::Promise> object instead of accepting a callback.
 
   my $tx = $ua->patch('example.com');
   my $tx = $ua->patch('http://example.com' => {Accept => '*/*'} => 'Content!');
-  my $tx = $ua->patch(
-    'http://example.com' => {Accept => '*/*'} => form => {a => 'b'});
-  my $tx = $ua->patch(
-    'http://example.com' => {Accept => '*/*'} => json => {a => 'b'});
+  my $tx = $ua->patch('http://example.com' => {Accept => '*/*'} => form => {a => 'b'});
+  my $tx = $ua->patch('http://example.com' => {Accept => '*/*'} => json => {a => 'b'});
 
-Perform blocking C<PATCH> request and return resulting
-L<Mojo::Transaction::HTTP> object, takes the same arguments as
-L<Mojo::UserAgent::Transactor/"tx"> (except for the C<PATCH> method, which is
-implied). You can also append a callback to perform requests non-blocking.
+Perform blocking C<PATCH> request and return resulting L<Mojo::Transaction::HTTP> object, takes the same arguments as
+L<Mojo::UserAgent::Transactor/"tx"> (except for the C<PATCH> method, which is implied). You can also append a callback
+to perform requests non-blocking.
 
   $ua->patch('http://example.com' => json => {a => 'b'} => sub {
     my ($ua, $tx) = @_;
@@ -932,8 +882,8 @@ implied). You can also append a callback to perform requests non-blocking.
 
   my $promise = $ua->patch_p('http://example.com');
 
-Same as L</"patch">, but performs all requests non-blocking and returns a
-L<Mojo::Promise> object instead of accepting a callback.
+Same as L</"patch">, but performs all requests non-blocking and returns a L<Mojo::Promise> object instead of accepting
+a callback.
 
   $ua->patch_p('http://example.com' => json => {a => 'b'})->then(sub {
     my $tx = shift;
@@ -947,15 +897,12 @@ L<Mojo::Promise> object instead of accepting a callback.
 
   my $tx = $ua->post('example.com');
   my $tx = $ua->post('http://example.com' => {Accept => '*/*'} => 'Content!');
-  my $tx = $ua->post(
-    'http://example.com' => {Accept => '*/*'} => form => {a => 'b'});
-  my $tx = $ua->post(
-    'http://example.com' => {Accept => '*/*'} => json => {a => 'b'});
+  my $tx = $ua->post('http://example.com' => {Accept => '*/*'} => form => {a => 'b'});
+  my $tx = $ua->post('http://example.com' => {Accept => '*/*'} => json => {a => 'b'});
 
-Perform blocking C<POST> request and return resulting
-L<Mojo::Transaction::HTTP> object, takes the same arguments as
-L<Mojo::UserAgent::Transactor/"tx"> (except for the C<POST> method, which is
-implied). You can also append a callback to perform requests non-blocking.
+Perform blocking C<POST> request and return resulting L<Mojo::Transaction::HTTP> object, takes the same arguments as
+L<Mojo::UserAgent::Transactor/"tx"> (except for the C<POST> method, which is implied). You can also append a callback
+to perform requests non-blocking.
 
   $ua->post('http://example.com' => json => {a => 'b'} => sub {
     my ($ua, $tx) = @_;
@@ -967,8 +914,8 @@ implied). You can also append a callback to perform requests non-blocking.
 
   my $promise = $ua->post_p('http://example.com');
 
-Same as L</"post">, but performs all requests non-blocking and returns a
-L<Mojo::Promise> object instead of accepting a callback.
+Same as L</"post">, but performs all requests non-blocking and returns a L<Mojo::Promise> object instead of accepting a
+callback.
 
   $ua->post_p('http://example.com' => json => {a => 'b'})->then(sub {
     my $tx = shift;
@@ -982,14 +929,11 @@ L<Mojo::Promise> object instead of accepting a callback.
 
   my $tx = $ua->put('example.com');
   my $tx = $ua->put('http://example.com' => {Accept => '*/*'} => 'Content!');
-  my $tx = $ua->put(
-    'http://example.com' => {Accept => '*/*'} => form => {a => 'b'});
-  my $tx = $ua->put(
-    'http://example.com' => {Accept => '*/*'} => json => {a => 'b'});
+  my $tx = $ua->put('http://example.com' => {Accept => '*/*'} => form => {a => 'b'});
+  my $tx = $ua->put('http://example.com' => {Accept => '*/*'} => json => {a => 'b'});
 
-Perform blocking C<PUT> request and return resulting L<Mojo::Transaction::HTTP>
-object, takes the same arguments as L<Mojo::UserAgent::Transactor/"tx"> (except
-for the C<PUT> method, which is implied). You can also append a callback to
+Perform blocking C<PUT> request and return resulting L<Mojo::Transaction::HTTP> object, takes the same arguments as
+L<Mojo::UserAgent::Transactor/"tx"> (except for the C<PUT> method, which is implied). You can also append a callback to
 perform requests non-blocking.
 
   $ua->put('http://example.com' => json => {a => 'b'} => sub {
@@ -1002,8 +946,8 @@ perform requests non-blocking.
 
   my $promise = $ua->put_p('http://example.com');
 
-Same as L</"put">, but performs all requests non-blocking and returns a
-L<Mojo::Promise> object instead of accepting a callback.
+Same as L</"put">, but performs all requests non-blocking and returns a L<Mojo::Promise> object instead of accepting a
+callback.
 
   $ua->put_p('http://example.com' => json => {a => 'b'})->then(sub {
     my $tx = shift;
@@ -1017,9 +961,8 @@ L<Mojo::Promise> object instead of accepting a callback.
 
   my $tx = $ua->start(Mojo::Transaction::HTTP->new);
 
-Perform blocking request for a custom L<Mojo::Transaction::HTTP> object, which
-can be prepared manually or with L</"build_tx">. You can also append a callback
-to perform requests non-blocking.
+Perform blocking request for a custom L<Mojo::Transaction::HTTP> object, which can be prepared manually or with
+L</"build_tx">. You can also append a callback to perform requests non-blocking.
 
   my $tx = $ua->build_tx(GET => 'http://example.com');
   $ua->start($tx => sub {
@@ -1032,8 +975,8 @@ to perform requests non-blocking.
 
   my $promise = $ua->start_p(Mojo::Transaction::HTTP->new);
 
-Same as L</"start">, but performs all requests non-blocking and returns a
-L<Mojo::Promise> object instead of accepting a callback.
+Same as L</"start">, but performs all requests non-blocking and returns a L<Mojo::Promise> object instead of accepting
+a callback.
 
   my $tx = $ua->build_tx(GET => 'http://example.com');
   $ua->start_p($tx)->then(sub {
@@ -1047,13 +990,11 @@ L<Mojo::Promise> object instead of accepting a callback.
 =head2 websocket
 
   $ua->websocket('ws://example.com' => sub {...});
-  $ua->websocket(
-    'ws://example.com' => {DNT => 1} => ['v1.proto'] => sub {...});
+  $ua->websocket('ws://example.com' => {DNT => 1} => ['v1.proto'] => sub {...});
 
-Open a non-blocking WebSocket connection with transparent handshake, takes the
-same arguments as L<Mojo::UserAgent::Transactor/"websocket">. The callback will
-receive either a L<Mojo::Transaction::WebSocket> or L<Mojo::Transaction::HTTP>
-object, depending on if the handshake was successful.
+Open a non-blocking WebSocket connection with transparent handshake, takes the same arguments as
+L<Mojo::UserAgent::Transactor/"websocket">. The callback will receive either a L<Mojo::Transaction::WebSocket> or
+L<Mojo::Transaction::HTTP> object, depending on if the handshake was successful.
 
   $ua->websocket('wss://example.com/echo' => ['v1.proto'] => sub {
     my ($ua, $tx) = @_;
@@ -1072,9 +1013,8 @@ object, depending on if the handshake was successful.
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
 
-You can activate C<permessage-deflate> compression by setting the
-C<Sec-WebSocket-Extensions> header, this can result in much better performance,
-but also increases memory usage by up to 300KiB per connection.
+You can activate C<permessage-deflate> compression by setting the C<Sec-WebSocket-Extensions> header, this can result
+in much better performance, but also increases memory usage by up to 300KiB per connection.
 
   $ua->websocket('ws://example.com/foo' => {
     'Sec-WebSocket-Extensions' => 'permessage-deflate'
@@ -1084,8 +1024,7 @@ but also increases memory usage by up to 300KiB per connection.
 
   my $promise = $ua->websocket_p('ws://example.com');
 
-Same as L</"websocket">, but returns a L<Mojo::Promise> object instead of
-accepting a callback.
+Same as L</"websocket">, but returns a L<Mojo::Promise> object instead of accepting a callback.
 
   $ua->websocket_p('wss://example.com/echo')->then(sub {
     my $tx = shift;
@@ -1105,8 +1044,8 @@ accepting a callback.
 
 =head1 DEBUGGING
 
-You can set the C<MOJO_CLIENT_DEBUG> environment variable to get some advanced
-diagnostics information printed to C<STDERR>.
+You can set the C<MOJO_CLIENT_DEBUG> environment variable to get some advanced diagnostics information printed to
+C<STDERR>.
 
   MOJO_CLIENT_DEBUG=1
 
