@@ -15,8 +15,7 @@ use Mojo::Util qw(encode url_escape);
 use Mojo::WebSocket qw(challenge client_handshake);
 
 has compressed => sub { $ENV{MOJO_GZIP} // 1 };
-has generators =>
-  sub { {form => \&_form, json => \&_json, multipart => \&_multipart} };
+has generators => sub { {form => \&_form, json => \&_json, multipart => \&_multipart} };
 has name => 'Mojolicious (Perl)';
 
 sub add_generator { $_[0]->generators->{$_[1]} = $_[2] and return $_[0] }
@@ -34,8 +33,7 @@ sub endpoint {
   # Proxy for normal HTTP requests
   my $socks;
   if (my $proxy = $req->proxy) { $socks = $proxy->protocol eq 'socks' }
-  return _proxy($tx, $proto, $host, $port)
-    if $proto eq 'http' && !$req->is_handshake && !$socks;
+  return _proxy($tx, $proto, $host, $port) if $proto eq 'http' && !$req->is_handshake && !$socks;
 
   return $proto, $host, $port;
 }
@@ -45,9 +43,8 @@ sub peer { _proxy($_[1], $_[0]->endpoint($_[1])) }
 sub promisify {
   my ($self, $promise, $tx) = @_;
   my $err = $tx->error;
-  return $promise->reject($err->{message}) if $err && !$err->{code};
-  return $promise->reject('WebSocket handshake failed')
-    if $tx->req->is_handshake && !$tx->is_websocket;
+  return $promise->reject($err->{message})              if $err                   && !$err->{code};
+  return $promise->reject('WebSocket handshake failed') if $tx->req->is_handshake && !$tx->is_websocket;
   $promise->resolve($tx);
 }
 
@@ -87,8 +84,7 @@ sub redirect {
   return undef if uc $req->method eq 'CONNECT';
 
   # Fix location without authority and/or scheme
-  return undef
-    unless my $location = $res->headers->every_header('Location')->[0];
+  return undef unless my $location = $res->headers->every_header('Location')->[0];
   $location = Mojo::URL->new($location);
   $location = $location->base($req->url)->to_abs unless $location->is_abs;
   my $proto = $location->protocol;
@@ -101,9 +97,9 @@ sub redirect {
     $new->req($clone);
   }
   else {
-    my $m       = uc $req->method;
-    my $headers = $new->req->method($code == 303 || $m eq 'POST' ? 'GET' : $m)
-      ->content->headers($req->headers->clone)->headers;
+    my $m = uc $req->method;
+    my $headers
+      = $new->req->method($code == 303 || $m eq 'POST' ? 'GET' : $m)->content->headers($req->headers->clone)->headers;
     $headers->remove($_) for grep {/^content-/i} @{$headers->names};
   }
   my $headers = $new->req->url($location)->headers;
@@ -192,8 +188,7 @@ sub _form {
   my @form   = map { $_ => $form->{$_} } sort keys %$form;
   if ($method eq 'GET' || $method eq 'HEAD') { $req->url->query->merge(@form) }
   else {
-    $req->body(
-      Mojo::Parameters->new(@form)->charset($options{charset})->to_string);
+    $req->body(Mojo::Parameters->new(@form)->charset($options{charset})->to_string);
     _type($headers, 'application/x-www-form-urlencoded');
   }
   return $tx;
@@ -240,8 +235,7 @@ sub _parts {
       if (my $file = delete $value->{file}) {
         $file = Mojo::Asset::File->new(path => $file) unless ref $file;
         $part->asset($file);
-        $value->{filename} //= path($file->path)->basename
-          if $file->isa('Mojo::Asset::File');
+        $value->{filename} //= path($file->path)->basename if $file->isa('Mojo::Asset::File');
       }
 
       # Memory
@@ -280,8 +274,7 @@ sub _proxy {
 
   my $req = $tx->req;
   if ($req->via_proxy && (my $proxy = $req->proxy)) {
-    return $proxy->protocol, $proxy->ihost,
-      $proxy->port // ($proto eq 'https' ? 443 : 80);
+    return $proxy->protocol, $proxy->ihost, $proxy->port // ($proto eq 'https' ? 443 : 80);
   }
 
   return $proto, $host, $port;
@@ -313,8 +306,7 @@ Mojo::UserAgent::Transactor - User agent transactor
 
 =head1 DESCRIPTION
 
-L<Mojo::UserAgent::Transactor> is the transaction building and manipulation
-framework used by L<Mojo::UserAgent>.
+L<Mojo::UserAgent::Transactor> is the transaction building and manipulation framework used by L<Mojo::UserAgent>.
 
 =head1 GENERATORS
 
@@ -324,8 +316,7 @@ These content generators are available by default.
 
   $t->tx(POST => 'http://example.com' => form => {a => 'b'});
 
-Generate query string, C<application/x-www-form-urlencoded> or
-C<multipart/form-data> content. See L</"tx"> for more.
+Generate query string, C<application/x-www-form-urlencoded> or C<multipart/form-data> content. See L</"tx"> for more.
 
 =head2 json
 
@@ -348,30 +339,26 @@ L<Mojo::UserAgent::Transactor> implements the following attributes.
   my $bool = $t->compressed;
   $t       = $t->compressed($bool);
 
-Try to negotiate compression for the response content and decompress it
-automatically, defaults to the value of the C<MOJO_GZIP> environment variable or
-true.
+Try to negotiate compression for the response content and decompress it automatically, defaults to the value of the
+C<MOJO_GZIP> environment variable or true.
 
 =head2 generators
 
   my $generators = $t->generators;
   $t             = $t->generators({foo => sub {...}});
 
-Registered content generators, by default only C<form>, C<json> and C<multipart>
-are already defined.
+Registered content generators, by default only C<form>, C<json> and C<multipart> are already defined.
 
 =head2 name
 
   my $name = $t->name;
   $t       = $t->name('Mojolicious');
 
-Value for C<User-Agent> request header of generated transactions, defaults to
-C<Mojolicious (Perl)>.
+Value for C<User-Agent> request header of generated transactions, defaults to C<Mojolicious (Perl)>.
 
 =head1 METHODS
 
-L<Mojo::UserAgent::Transactor> inherits all methods from L<Mojo::Base> and
-implements the following new ones.
+L<Mojo::UserAgent::Transactor> inherits all methods from L<Mojo::Base> and implements the following new ones.
 
 =head2 add_generator
 
@@ -400,22 +387,20 @@ Actual peer for transaction.
 
   $t->promisify(Mojo::Promise->new, Mojo::Transaction::HTTP->new);
 
-Resolve or reject L<Mojo::Promise> object with L<Mojo::Transaction::HTTP>
-object.
+Resolve or reject L<Mojo::Promise> object with L<Mojo::Transaction::HTTP> object.
 
 =head2 proxy_connect
 
   my $tx = $t->proxy_connect(Mojo::Transaction::HTTP->new);
 
-Build L<Mojo::Transaction::HTTP> proxy C<CONNECT> request for transaction if
-possible.
+Build L<Mojo::Transaction::HTTP> proxy C<CONNECT> request for transaction if possible.
 
 =head2 redirect
 
   my $tx = $t->redirect(Mojo::Transaction::HTTP->new);
 
-Build L<Mojo::Transaction::HTTP> follow-up request for C<301>, C<302>, C<303>,
-C<307> or C<308> redirect response if possible.
+Build L<Mojo::Transaction::HTTP> follow-up request for C<301>, C<302>, C<303>, C<307> or C<308> redirect response if
+possible.
 
 =head2 tx
 
@@ -427,15 +412,12 @@ C<307> or C<308> redirect response if possible.
   my $tx = $t->tx(PUT  => 'http://example.com' => json => {a => 'b'});
   my $tx = $t->tx(PUT  => 'https://example.com' => multipart => ['a', 'b']);
   my $tx = $t->tx(POST => 'example.com' => {Accept => '*/*'} => 'Content!');
-  my $tx = $t->tx(
-    PUT => 'example.com' => {Accept => '*/*'} => form => {a => 'b'});
-  my $tx = $t->tx(
-    PUT => 'example.com' => {Accept => '*/*'} => json => {a => 'b'});
-  my $tx = $t->tx(
-    PUT => 'example.com' => {Accept => '*/*'} => multipart => ['a', 'b']);
+  my $tx = $t->tx(PUT => 'example.com' => {Accept => '*/*'} => form => {a => 'b'});
+  my $tx = $t->tx(PUT => 'example.com' => {Accept => '*/*'} => json => {a => 'b'});
+  my $tx = $t->tx(PUT => 'example.com' => {Accept => '*/*'} => multipart => ['a', 'b']);
 
-Versatile general purpose L<Mojo::Transaction::HTTP> transaction builder for
-requests, with support for L</"GENERATORS">.
+Versatile general purpose L<Mojo::Transaction::HTTP> transaction builder for requests, with support for
+L</"GENERATORS">.
 
   # Generate and inspect custom GET request with DNT header and content
   say $t->tx(GET => 'example.com' => {DNT => 1} => 'Bye!')->req->to_string;
@@ -448,64 +430,52 @@ requests, with support for L</"GENERATORS">.
   my $tx = $t->tx(PUT => 'http://example.com');
   $tx->req->content->asset(Mojo::Asset::File->new(path => '/foo.txt'));
 
-The C<json> content generator uses L<Mojo::JSON> for encoding and sets the
-content type to C<application/json>.
+The C<json> content generator uses L<Mojo::JSON> for encoding and sets the content type to C<application/json>.
 
   # POST request with "application/json" content
-  my $tx = $t->tx(
-    POST => 'http://example.com' => json => {a => 'b', c => [1, 2, 3]});
+  my $tx = $t->tx(POST => 'http://example.com' => json => {a => 'b', c => [1, 2, 3]});
 
-The C<form> content generator will automatically use query parameters for
-C<GET> and C<HEAD> requests.
+The C<form> content generator will automatically use query parameters for C<GET> and C<HEAD> requests.
 
   # GET request with query parameters
   my $tx = $t->tx(GET => 'http://example.com' => form => {a => 'b'});
 
-For all other request methods the C<application/x-www-form-urlencoded> content
-type is used.
+For all other request methods the C<application/x-www-form-urlencoded> content type is used.
 
   # POST request with "application/x-www-form-urlencoded" content
-  my $tx = $t->tx(
-    POST => 'http://example.com' => form => {a => 'b', c => 'd'});
+  my $tx = $t->tx(POST => 'http://example.com' => form => {a => 'b', c => 'd'});
 
 Parameters may be encoded with the C<charset> option.
 
   # PUT request with Shift_JIS encoded form values
-  my $tx = $t->tx(
-    PUT => 'example.com' => form => {a => 'b'} => charset => 'Shift_JIS');
+  my $tx = $t->tx(PUT => 'example.com' => form => {a => 'b'} => charset => 'Shift_JIS');
 
 An array reference can be used for multiple form values sharing the same name.
 
   # POST request with form values sharing the same name
-  my $tx = $t->tx(
-    POST => 'http://example.com' => form => {a => ['b', 'c', 'd']});
+  my $tx = $t->tx(POST => 'http://example.com' => form => {a => ['b', 'c', 'd']});
 
-A hash reference with a C<content> or C<file> value can be used to switch to
-the C<multipart/form-data> content type for file uploads.
+A hash reference with a C<content> or C<file> value can be used to switch to the C<multipart/form-data> content type
+for file uploads.
 
   # POST request with "multipart/form-data" content
-  my $tx = $t->tx(
-    POST => 'http://example.com' => form => {mytext => {content => 'lala'}});
+  my $tx = $t->tx(POST => 'http://example.com' => form => {mytext => {content => 'lala'}});
 
   # POST request with multiple files sharing the same name
-  my $tx = $t->tx(POST => 'http://example.com' =>
-    form => {mytext => [{content => 'first'}, {content => 'second'}]});
+  my $tx = $t->tx(POST => 'http://example.com' => form => {mytext => [{content => 'first'}, {content => 'second'}]});
 
-The C<file> value should contain the path to the file you want to upload or an
-asset object, like L<Mojo::Asset::File> or L<Mojo::Asset::Memory>.
+The C<file> value should contain the path to the file you want to upload or an asset object, like L<Mojo::Asset::File>
+or L<Mojo::Asset::Memory>.
 
   # POST request with upload streamed from file
-  my $tx = $t->tx(
-    POST => 'http://example.com' => form => {mytext => {file => '/foo.txt'}});
+  my $tx = $t->tx(POST => 'http://example.com' => form => {mytext => {file => '/foo.txt'}});
 
   # POST request with upload streamed from asset
   my $asset = Mojo::Asset::Memory->new->add_chunk('lalala');
-  my $tx    = $t->tx(
-    POST => 'http://example.com' => form => {mytext => {file => $asset}});
+  my $tx    = $t->tx(POST => 'http://example.com' => form => {mytext => {file => $asset}});
 
-A C<filename> value will be generated automatically, but can also be set
-manually if necessary. All remaining values in the hash reference get merged
-into the C<multipart/form-data> content as headers.
+A C<filename> value will be generated automatically, but can also be set manually if necessary. All remaining values in
+the hash reference get merged into the C<multipart/form-data> content as headers.
 
   # POST request with form values and customized upload (filename and header)
   my $tx = $t->tx(POST => 'http://example.com' => form => {
@@ -518,31 +488,27 @@ into the C<multipart/form-data> content as headers.
     }
   });
 
-The C<multipart/form-data> content type can also be enforced by setting the
-C<Content-Type> header manually.
+The C<multipart/form-data> content type can also be enforced by setting the C<Content-Type> header manually.
 
   # Force "multipart/form-data"
   my $headers = {'Content-Type' => 'multipart/form-data'};
   my $tx = $t->tx(POST => 'example.com' => $headers => form => {a => 'b'});
 
-The C<multipart> content generator can be used to build custom multipart
-requests and does not set a content type.
+The C<multipart> content generator can be used to build custom multipart requests and does not set a content type.
 
   # POST request with multipart content ("foo" and "bar")
   my $tx = $t->tx(POST => 'http://example.com' => multipart => ['foo', 'bar']);
 
-Similar to the C<form> content generator you can also pass hash references with
-C<content> or C<file> values, as well as headers.
+Similar to the C<form> content generator you can also pass hash references with C<content> or C<file> values, as well
+as headers.
 
   # POST request with multipart content streamed from file
-  my $tx = $t->tx(
-    POST => 'http://example.com' => multipart => [{file => '/foo.txt'}]);
+  my $tx = $t->tx(POST => 'http://example.com' => multipart => [{file => '/foo.txt'}]);
 
   # PUT request with multipart content streamed from asset
   my $headers = {'Content-Type' => 'multipart/custom'};
   my $asset   = Mojo::Asset::Memory->new->add_chunk('lalala');
-  my $tx      = $t->tx(
-    PUT => 'http://example.com' => $headers => multipart => [{file => $asset}]);
+  my $tx      = $t->tx(PUT => 'http://example.com' => $headers => multipart => [{file => $asset}]);
 
   # POST request with multipart content and custom headers
   my $tx = $t->tx(POST => 'http://example.com' => multipart => [
@@ -562,16 +528,14 @@ C<content> or C<file> values, as well as headers.
 
   my $tx = $t->upgrade(Mojo::Transaction::HTTP->new);
 
-Build L<Mojo::Transaction::WebSocket> follow-up transaction for WebSocket
-handshake if possible.
+Build L<Mojo::Transaction::WebSocket> follow-up transaction for WebSocket handshake if possible.
 
 =head2 websocket
 
   my $tx = $t->websocket('ws://example.com');
   my $tx = $t->websocket('ws://example.com' => {DNT => 1} => ['v1.proto']);
 
-Versatile L<Mojo::Transaction::HTTP> transaction builder for WebSocket
-handshake requests.
+Versatile L<Mojo::Transaction::HTTP> transaction builder for WebSocket handshake requests.
 
 =head1 SEE ALSO
 
