@@ -21,8 +21,7 @@ use Time::HiRes        ();
 use Unicode::Normalize ();
 
 # Check for monotonic clock support
-use constant MONOTONIC =>
-  eval { !!Time::HiRes::clock_gettime(Time::HiRes::CLOCK_MONOTONIC()) };
+use constant MONOTONIC => eval { !!Time::HiRes::clock_gettime(Time::HiRes::CLOCK_MONOTONIC()) };
 
 # Punycode bootstring parameters
 use constant {
@@ -40,11 +39,9 @@ use constant {
 my %ENTITIES;
 {
   # Don't use Mojo::File here due to circular dependencies
-  my $path
-    = File::Spec->catfile(dirname(__FILE__), 'resources', 'html_entities.txt');
+  my $path = File::Spec->catfile(dirname(__FILE__), 'resources', 'html_entities.txt');
 
-  open my $file, '<', $path
-    or croak "Unable to open html entities file ($path): $!";
+  open my $file, '<', $path or croak "Unable to open html entities file ($path): $!";
   my $lines = do { local $/; <$file> };
 
   for my $line (split "\n", $lines) {
@@ -54,13 +51,7 @@ my %ENTITIES;
 }
 
 # Characters that should be escaped in XML
-my %XML = (
-  '&'  => '&amp;',
-  '<'  => '&lt;',
-  '>'  => '&gt;',
-  '"'  => '&quot;',
-  '\'' => '&#39;'
-);
+my %XML = ('&' => '&amp;', '<' => '&lt;', '>' => '&gt;', '"' => '&quot;', '\'' => '&#39;');
 
 # "Sun, 06 Nov 1994 08:49:37 GMT" and "Sunday, 06-Nov-94 08:49:37 GMT"
 my $EXPIRES_RE = qr/(\w+\W+\d+\W+\w+\W+\d+\W+\d+:\d+:\d+\W*\w+)/;
@@ -92,9 +83,7 @@ monkey_patch(__PACKAGE__, 'sha1_sum',      \&sha1_hex);
 
 # Use a monotonic clock if possible
 monkey_patch(__PACKAGE__, 'steady_time',
-  MONOTONIC
-  ? sub () { Time::HiRes::clock_gettime(Time::HiRes::CLOCK_MONOTONIC()) }
-  : \&Time::HiRes::time);
+  MONOTONIC ? sub () { Time::HiRes::clock_gettime(Time::HiRes::CLOCK_MONOTONIC()) } : \&Time::HiRes::time);
 
 sub camelize {
   my $str = shift;
@@ -127,8 +116,7 @@ sub decamelize {
 
 sub decode {
   my ($encoding, $bytes) = @_;
-  return undef
-    unless eval { $bytes = _encoding($encoding)->decode("$bytes", 1); 1 };
+  return undef unless eval { $bytes = _encoding($encoding)->decode("$bytes", 1); 1 };
   return $bytes;
 }
 
@@ -157,8 +145,7 @@ sub extract_usage {
 sub getopt {
   my ($array, $opts) = map { ref $_[0] eq 'ARRAY' ? shift : $_ } \@ARGV, [];
 
-  my $save = Getopt::Long::Configure(qw(default no_auto_abbrev no_ignore_case),
-    @$opts);
+  my $save   = Getopt::Long::Configure(qw(default no_auto_abbrev no_ignore_case), @$opts);
   my $result = GetOptionsFromArray $array, @_;
   Getopt::Long::Configure($save);
 
@@ -174,8 +161,7 @@ sub gunzip {
 
 sub gzip {
   my $uncompressed = shift;
-  IO::Compress::Gzip::gzip \$uncompressed, \my $compressed
-    or croak "Couldn't gzip: $IO::Compress::Gzip::GzipError";
+  IO::Compress::Gzip::gzip \$uncompressed, \my $compressed or croak "Couldn't gzip: $IO::Compress::Gzip::GzipError";
   return $compressed;
 }
 
@@ -369,9 +355,7 @@ sub url_escape {
   if ($pattern) {
     unless (exists $PATTERN{$pattern}) {
       (my $quoted = $pattern) =~ s!([/\$\[])!\\$1!g;
-      $PATTERN{$pattern}
-        = eval "sub { \$_[0] =~ s/([$quoted])/sprintf '%%%02X', ord \$1/ge }"
-        or croak $@;
+      $PATTERN{$pattern} = eval "sub { \$_[0] =~ s/([$quoted])/sprintf '%%%02X', ord \$1/ge }" or croak $@;
     }
     $PATTERN{$pattern}->($str);
   }
@@ -399,8 +383,7 @@ sub xor_encode {
   # Encode with variable key length
   my $len    = length $key;
   my $buffer = my $output = '';
-  $output .= $buffer ^ $key
-    while length($buffer = substr($input, 0, $len, '')) == $len;
+  $output .= $buffer ^ $key while length($buffer = substr($input, 0, $len, '')) == $len;
   return $output .= $buffer ^ substr($key, 0, length $buffer, '');
 }
 
@@ -433,8 +416,7 @@ sub _entity {
   my $rest = my $last = '';
   while (length $name) {
     return $ENTITIES{$name} . reverse $rest
-      if exists $ENTITIES{$name}
-      && (!$attr || $name =~ /;$/ || $last !~ /[A-Za-z0-9=]/);
+      if exists $ENTITIES{$name} && (!$attr || $name =~ /;$/ || $last !~ /[A-Za-z0-9=]/);
     $rest .= $last = chop $name;
   }
   return '&' . reverse $rest;
@@ -548,8 +530,7 @@ L<Mojo::Util> provides portable utility functions for L<Mojo>.
 
 =head1 FUNCTIONS
 
-L<Mojo::Util> implements the following functions, which can be imported
-individually.
+L<Mojo::Util> implements the following functions, which can be imported individually.
 
 =head2 b64_decode
 
@@ -628,16 +609,14 @@ Convert C<CamelCase> string to C<snake_case> and replace C<::> with C<->.
 
   my $chars = decode 'UTF-8', $bytes;
 
-Decode bytes to characters with L<Encode>, or return C<undef> if decoding
-failed.
+Decode bytes to characters with L<Encode>, or return C<undef> if decoding failed.
 
 =head2 deprecated
 
   deprecated 'foo is DEPRECATED in favor of bar';
 
-Warn about deprecated feature from perspective of caller. You can also set the
-C<MOJO_FATAL_DEPRECATIONS> environment variable to make them die instead with
-L<Carp>.
+Warn about deprecated feature from perspective of caller. You can also set the C<MOJO_FATAL_DEPRECATIONS> environment
+variable to make them die instead with L<Carp>.
 
 =head2 dumper
 
@@ -656,8 +635,8 @@ Encode characters to bytes with L<Encode>.
   my $usage = extract_usage;
   my $usage = extract_usage '/home/sri/foo.pod';
 
-Extract usage message from the SYNOPSIS section of a file containing POD
-documentation, defaults to using the file this function was called from.
+Extract usage message from the SYNOPSIS section of a file containing POD documentation, defaults to using the file this
+function was called from.
 
   # "Usage: APPLICATION test [OPTIONS]\n"
   extract_usage;
@@ -683,9 +662,8 @@ documentation, defaults to using the file this function was called from.
     't|timeout=i' => \my $timeout,
     'v|verbose'   => \my $verbose;
 
-Extract options from an array reference with L<Getopt::Long>, but without
-changing its global configuration, defaults to using C<@ARGV>. The configuration
-options C<no_auto_abbrev> and C<no_ignore_case> are enabled by default.
+Extract options from an array reference with L<Getopt::Long>, but without changing its global configuration, defaults
+to using C<@ARGV>. The configuration options C<no_auto_abbrev> and C<no_ignore_case> are enabled by default.
 
   # Extract "charset" option
   getopt ['--charset', 'UTF-8'], 'charset=s' => \my $charset;
@@ -716,8 +694,8 @@ Generate HMAC-SHA1 checksum for bytes with L<Digest::SHA>.
 
   my $str = html_attr_unescape $escaped;
 
-Same as L</"html_unescape">, but handles special rules from the
-L<HTML Living Standard|https://html.spec.whatwg.org> for HTML attributes.
+Same as L</"html_unescape">, but handles special rules from the L<HTML Living Standard|https://html.spec.whatwg.org>
+for HTML attributes.
 
   # "foo=bar&ltest=baz"
   html_attr_unescape 'foo=bar&ltest=baz';
@@ -738,8 +716,8 @@ Unescape all HTML entities in string.
 
   my $str = humanize_bytes 1234;
 
-Turn number of bytes into a simplified human readable format. Note that this
-function is B<EXPERIMENTAL> and might change without warning!
+Turn number of bytes into a simplified human readable format. Note that this function is B<EXPERIMENTAL> and might
+change without warning!
 
   # "1B"
   humanize_bytes 1;
@@ -784,8 +762,7 @@ Monkey patch functions into package.
 
   my $str = punycode_decode $punycode;
 
-Punycode decode string as described in
-L<RFC 3492|http://tools.ietf.org/html/rfc3492>.
+Punycode decode string as described in L<RFC 3492|http://tools.ietf.org/html/rfc3492>.
 
   # "bücher"
   punycode_decode 'bcher-kva';
@@ -794,8 +771,7 @@ L<RFC 3492|http://tools.ietf.org/html/rfc3492>.
 
   my $punycode = punycode_encode $str;
 
-Punycode encode string as described in
-L<RFC 3492|http://tools.ietf.org/html/rfc3492>.
+Punycode encode string as described in L<RFC 3492|http://tools.ietf.org/html/rfc3492>.
 
   # "bcher-kva"
   punycode_encode 'bücher';
@@ -810,8 +786,7 @@ Quote string.
 
   my $guard = scope_guard sub {...};
 
-Create anonymous scope guard object that will execute the passed callback when
-the object is destroyed.
+Create anonymous scope guard object that will execute the passed callback when the object is destroyed.
 
   # Execute closure at end of scope
   {
@@ -845,12 +820,10 @@ Generate SHA1 checksum for bytes with L<Digest::SHA>.
   my $slug = slugify $string;
   my $slug = slugify $string, $bool;
 
-Returns a URL slug generated from the input string. Non-word characters are
-removed, the string is trimmed and lowercased, and whitespace characters are
-replaced by a dash. By default, non-ASCII characters are normalized to ASCII
-word characters or removed, but if a true value is passed as the second
-parameter, all word characters will be allowed in the result according to
-unicode semantics.
+Returns a URL slug generated from the input string. Non-word characters are removed, the string is trimmed and
+lowercased, and whitespace characters are replaced by a dash. By default, non-ASCII characters are normalized to ASCII
+word characters or removed, but if a true value is passed as the second parameter, all word characters will be allowed
+in the result according to unicode semantics.
 
   # "joel-is-a-slug"
   slugify 'Joel is a slug';
@@ -865,15 +838,14 @@ unicode semantics.
 
   my $tree = split_cookie_header 'a=b; expires=Thu, 07 Aug 2008 07:07:59 GMT';
 
-Same as L</"split_header">, but handles C<expires> values from
-L<RFC 6265|http://tools.ietf.org/html/rfc6265>.
+Same as L</"split_header">, but handles C<expires> values from L<RFC 6265|http://tools.ietf.org/html/rfc6265>.
 
 =head2 split_header
 
    my $tree = split_header 'foo="bar baz"; test=123, yada';
 
-Split HTTP header value into key/value pairs, each comma separated part gets
-its own array reference, and keys without a value get C<undef> assigned.
+Split HTTP header value into key/value pairs, each comma separated part gets its own array reference, and keys without
+a value get C<undef> assigned.
 
   # "one"
   split_header('one; two="three four", five=six')->[0][0];
@@ -894,9 +866,8 @@ its own array reference, and keys without a value get C<undef> assigned.
 
   my $time = steady_time;
 
-High resolution time elapsed from an arbitrary fixed point in the past,
-resilient to time jumps if a monotonic clock is available through
-L<Time::HiRes>.
+High resolution time elapsed from an arbitrary fixed point in the past, resilient to time jumps if a monotonic clock is
+available through L<Time::HiRes>.
 
 =head2 tablify
 
@@ -945,9 +916,8 @@ Unquote string.
   my $escaped = url_escape $str;
   my $escaped = url_escape $str, '^A-Za-z0-9\-._~';
 
-Percent encode unsafe characters in string as described in
-L<RFC 3986|http://tools.ietf.org/html/rfc3986>, the pattern used defaults to
-C<^A-Za-z0-9\-._~>.
+Percent encode unsafe characters in string as described in L<RFC 3986|http://tools.ietf.org/html/rfc3986>, the pattern
+used defaults to C<^A-Za-z0-9\-._~>.
 
   # "foo%3Bbar"
   url_escape 'foo;bar';
@@ -956,8 +926,7 @@ C<^A-Za-z0-9\-._~>.
 
   my $str = url_unescape $escaped;
 
-Decode percent encoded characters in string as described in
-L<RFC 3986|http://tools.ietf.org/html/rfc3986>.
+Decode percent encoded characters in string as described in L<RFC 3986|http://tools.ietf.org/html/rfc3986>.
 
   # "foo;bar"
   url_unescape 'foo%3Bbar';
@@ -966,8 +935,8 @@ L<RFC 3986|http://tools.ietf.org/html/rfc3986>.
 
   my $escaped = xml_escape $str;
 
-Escape unsafe characters C<&>, C<E<lt>>, C<E<gt>>, C<"> and C<'> in string, but
-do not escape L<Mojo::ByteStream> objects.
+Escape unsafe characters C<&>, C<E<lt>>, C<E<gt>>, C<"> and C<'> in string, but do not escape L<Mojo::ByteStream>
+objects.
 
   # "&lt;div&gt;"
   xml_escape '<div>';
